#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mwc-random
version:              0.15.3.0
visibility:           public
id:                   mwc-random-0.15.3.0-G3hlFeGWugUCkqS2WmIlTu
key:                  mwc-random-0.15.3.0-G3hlFeGWugUCkqS2WmIlTu
license:              BSD-2-Clause
copyright:            2009, 2010, 2011 Bryan O'\''Sullivan
maintainer:           Alexey Khudyakov <alexey.skladnoy@gmail.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/haskell/mwc-random
synopsis:             Fast, high quality pseudo random number generation
description:
    This package contains code for generating high quality random
    numbers that follow either a uniform or normal distribution.  The
    generated numbers are suitable for use in statistical applications.
    .
    The uniform PRNG uses Marsaglia'\''s MWC256 (also known as MWC8222)
    multiply-with-carry generator, which has a period of 2^8222 and
    fares well in tests of randomness.  It is also extremely fast,
    between 2 and 3 times faster than the Mersenne Twister.
    .
    Compared to the mersenne-random package, this package has a more
    convenient API, is faster, and supports more statistical
    distributions.

category:             Math, Statistics
abi:                  bcf49520b30a364d80e8c54eb31178b6
exposed:              True
exposed-modules:
    System.Random.MWC System.Random.MWC.CondensedTable
    System.Random.MWC.Distributions System.Random.MWC.SeedSource

import-dirs:          /usr/lib/ghc-9.6.6/site-local/mwc-random-0.15.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/mwc-random-0.15.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/mwc-random-0.15.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mwc-random
hs-libraries:         HSmwc-random-0.15.3.0-G3hlFeGWugUCkqS2WmIlTu
depends:
    base-4.18.2.1 math-functions-0.3.4.4-ByR5e67yQWHHWjOe4RAPKR
    primitive-0.9.1.0-IuEzc1i7B8w72ArTAK2GO5
    random-1.2.1.3-JQ5HMleih0QHEX58PgSIMQ time-1.12.2
    vector-0.13.2.0-5a59Ladt6HH20irTaXAFu7

haddock-interfaces:   /usr/share/doc/haskell-mwc-random/html/mwc-random.haddock
haddock-html:         /usr/share/doc/haskell-mwc-random/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

